.. currentmodule:: abjad.tools.sequencetools

yield_all_restricted_growth_functions_of_length
===============================================

.. autofunction:: yield_all_restricted_growth_functions_of_length
